# Welcome to kendrick


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Our lab, the Rijkserfgoedlaboratorium in Amsterdam, currently
experiments with direct ionization coupled with high resolution mass
spectrometry using Thermo ASAP probe and Orbitrap HRMS. This chemical
analysis technique seems well suited to analyze complex polymeric
samples. Visualization of the resulting data in so-called Kendrick mass
plots provides a means to efficiently explore this type of data.

Creating these plots with Excel is tedious and prone to error. Objective
of the *kendrick* Python package is to enable the automatic creation of
Kendrick mass plots from raw data. This open source package is developed
out in the open and will be made available for installation as soon as
possible.

If you are curious and can’t wait for a pip installable package, take a
look at our [documentation](https://fligt.github.io/kendrick/) and
[notebooks](https://github.com/fligt/kendrick/tree/master/notebooks).

Last updated: 2025-06-20
